==> ocre_v0_031.tgz: ocre-0.031/ocre/src/tarea.c <==

#include <errno.h>
#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <unistd.h>
#include <sys/wait.h>
/*
#include <sys/types.h>
*/

#include "misc.h"

void tarea (int *nh, char * fej, char ** argv, char ** env)
{
  int res;
  extern int errno;
  int n;
  n = fork () ;
  if ( n == 0) {
    res =  execve (fej, argv, env);
    printf ("tarea %s: res %d errno %d \n", fej, res, errno);
    exit (1);
    }
  *nh = n;
}

void tareaGnuplot (int *nnh, char *nfi, char * geom)
{
  char ** argv_gnuplot;
  char *disp;
  char envdisp[100];
  static char  * env2 [] = {"DISPLAY=:0.0", (char *)0L };
  if ((disp = getenv("DISPLAY")) != (char *)0L){
    strcpy  (envdisp, "DISPLAY=");
    strncat (envdisp, disp, 100);
    env2[0] = envdisp;
    }
  listaAarray (&argv_gnuplot, 4, "gnupot", "-geometry", geom, nfi);
  tarea (nnh, "/usr/bin/gnuplot", argv_gnuplot, env2) ;
}

void tareaScanimage (int *nnh, char *nfi, char *dev, char * resol,
                     char *tx, char *ty, char * modo)
{
  char ** argv_scanimage;
  static char  * env2 [] = { (char *)0L };
  listaAarray (&argv_scanimage, 13, "scanimage",
                 "-d", dev,
                 "--resolution", resol,
                 "-x", tx, "-y", ty,
                 "--mode", modo,
                 "--batch=zimag%03d.pgm", "--batch-count=1");
  tarea (nnh, "/usr/bin/scanimage", argv_scanimage, env2) ;
}

void para ()
{
  while (1) ;
}

void espera (int n)
{
  int nh;
  int resul;
/*
  for ( ; n != wait (&resul); )
    {
      printf (" 4\n");
    }
*/
  nh = 0;
  while (nh != n) {
    nh = wait (&resul);
    }
}

void termina (int n)
{
  espera (n);
  exit (0);
}

void tareaServ (int sfd[2], char *path, char ** argv, char ** env)
{
	int pfd[2];
	int pfdv[2];
	if (pipe(pfd) == -1)
		syserr ("pipe");
	if (pipe(pfdv) == -1)
		syserr ("pipe2");
	switch (fork()) {
	case -1:
		syserr ("fork");
	case 0:
		if (close(0) == -1)
			syserr ("close");
		if (dup(pfd[0]) != 0)
			fatal ("dup");
		if (close(1) == -1)
			syserr ("close5");
		if (dup(pfdv[1]) != 1)
			fatal ("dup2");
		if (close(pfd[0]) == -1 || close(pfd[1]) == -1)
			syserr ("close2");
		if (close(pfdv[0]) == -1 || close(pfdv[1]) == -1)
			syserr ("close6");
		execve(path, argv, env);
		syserr ("execve");
	}
	if (close(pfd[0]) == -1)
		syserr ("close3");
	if (close(pfdv[1]) == -1)
		syserr ("close7");
	sfd[0] = pfd  [1];
	sfd[1] = pfdv [0];
}

==> ocre_v0_033.tgz: ocre-0.033/ocre/src/tarea.c <==

#include <errno.h>
#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <unistd.h>
#include <sys/wait.h>
/*
#include <sys/types.h>
*/

#include "misc.h"

void tarea (int *nh, char * fej, char ** argv, char ** env)
{
  int res;
  extern int errno;
  int n;
  n = fork () ;
  if ( n == 0) {
    res =  execve (fej, argv, env);
    printf ("tarea %s: res %d errno %d \n", fej, res, errno);
    exit (1);
    }
  *nh = n;
}

void tareaGnuplot (int *nnh, char *nfi, char * geom)
{
  char ** argv_gnuplot;
  char *disp;
  char *home;
  char envdisp[100];
  char envhome[100];
  static char  * env2 [] = {"DISPLAY=:0.0", (char *)0L, (char *)0L };
  if ((disp = getenv("DISPLAY")) != (char *)0L){
    strcpy  (envdisp, "DISPLAY=");
    strncat (envdisp, disp, 100);
    env2[0] = envdisp;
    }
  if ((home = getenv("HOME")) != (char *)0L){
    strcpy  (envhome, "HOME=");
    strncat (envhome, home, 100);
    env2[1] = envhome;
    }
  listaAarray (&argv_gnuplot, 4, "gnupot", "-geometry", geom, nfi);
  tarea (nnh, "/usr/bin/gnuplot", argv_gnuplot, env2) ;
}

void tareaScanimage (int *nnh, char *nfi, char *dev, char * resol,
                     char *tx, char *ty, char *dx, char *dy, char *modo)
{
  char ** argv_scanimage;
  static char  * env2 [] = { (char *)0L };
  listaAarray (&argv_scanimage, 17, "scanimage",
                 "-d", dev,
                 "--resolution", resol,
                 "-x", tx, "-y", ty,
                 "-l", dx, "-t", dy,
                 "--mode", modo,
                 "--batch=zimag%03d.pgm", "--batch-count=1");
  tarea (nnh, "/usr/bin/scanimage", argv_scanimage, env2) ;
}

void para ()
{
  while (1) ;
}

void espera (int n)
{
  int nh;
  int resul;
/*
  for ( ; n != wait (&resul); )
    {
      printf (" 4\n");
    }
*/
  nh = 0;
  while (nh != n) {
    nh = wait (&resul);
    }
}

void termina (int n)
{
  espera (n);
  exit (0);
}

void tareaServ (int sfd[2], char *path, char ** argv, char ** env)
{
	int pfd[2];
	int pfdv[2];
	if (pipe(pfd) == -1)
		syserr ("pipe");
	if (pipe(pfdv) == -1)
		syserr ("pipe2");
	switch (fork()) {
	case -1:
		syserr ("fork");
	case 0:
		if (close(0) == -1)
			syserr ("close");
		if (dup(pfd[0]) != 0)
			fatal ("dup");
		if (close(1) == -1)
			syserr ("close5");
		if (dup(pfdv[1]) != 1)
			fatal ("dup2");
		if (close(pfd[0]) == -1 || close(pfd[1]) == -1)
			syserr ("close2");
		if (close(pfdv[0]) == -1 || close(pfdv[1]) == -1)
			syserr ("close6");
		execve(path, argv, env);
		syserr ("execve");
	}
	if (close(pfd[0]) == -1)
		syserr ("close3");
	if (close(pfdv[1]) == -1)
		syserr ("close7");
	sfd[0] = pfd  [1];
	sfd[1] = pfdv [0];
}
